@@ -300,7 +300,7 @@ class Course(dd.Model,mixins.Printable):
         Liste von :class:`CourseRequest`-Instanzen, 
         die in diesem Kurs eingetragen sind. 
         """
-        return ParticipantsByCourse.request(master_instance=self).data_iterator
+        return ParticipantsByCourse.request(self).data_iterator
         
     def candidates(self):
         u"""
@@ -308,7 +308,7 @@ class Course(dd.Model,mixins.Printable):
         die noch in keinem Kurs eingetragen sind, aber für diesen Kurs in Frage 
         kommen. 
         """
-        return CandidatesByCourse.request(master_instance=self).data_iterator
+        return CandidatesByCourse.request(self).data_iterator
         
 
         
@@ -383,13 +383,13 @@ class RegisterCandidate(dd.ChangeStateAction):
     required=dict(states=['candidate'])
     help_text=_("Register this candidate for this course.")
 
-    def run(self,obj,ar,**kw):
+    def run_from_ui(self,obj,ar,**kw):
         assert isinstance(obj,CourseRequest)
         if ar.master_instance is not None:
             obj.course = ar.master_instance
         if not obj.course:
             return ar.error.response(_("Cannot register to unknown course."))
-        kw = super(RegisterCandidate,self).run(obj,ar,**kw)
+        kw = super(RegisterCandidate,self).run_from_ui(obj,ar,**kw)
         kw.update(refresh_all=True)
         kw.update(message=_("%(person)s has been registered to %(course)s") % dict(
                 person=obj.person,course=obj.course))
@@ -400,11 +400,11 @@ class UnRegisterCandidate(dd.ChangeStateAction):
     required=dict(states=['registered'])
     help_text=_("Unregister this candidate from this course.")
 
-    def run(self,obj,ar,**kw):
+    def run_from_ui(self,obj,ar,**kw):
         assert isinstance(obj,CourseRequest)
         course = obj.course
         obj.course = None
-        kw = super(UnRegisterCandidate,self).run(obj,ar,**kw)
+        kw = super(UnRegisterCandidate,self).run_from_ui(obj,ar,**kw)
         kw.update(refresh_all=True)
         kw.update(message=_("%(person)s has been unregistered from %(course)s") 
             % dict(person=obj.person,course=course))
