@@ -88,6 +88,7 @@ households = dd.resolve_app('households')
 properties = dd.resolve_app('properties')
 pcsw = dd.resolve_app('pcsw')
 
+
 from lino.mixins.printable import decfmt
 
 class PeriodsField(models.DecimalField):
@@ -158,14 +159,19 @@ class Budget(mixins.AutoUser,mixins.CachedPrintable,mixins.Duplicable):
     #~ closed = models.BooleanField(verbose_name=_("Closed"))
     print_todos = models.BooleanField(
         verbose_name=_("Print to-do list"),
-        help_text="""\
+        help_text=_("""\
 Einträge im Feld "To-do" werden nur ausgedruckt, 
 wenn die Option "To-dos drucken" des Budgets angekreuzt ist. 
 Diese Option wird aber momentan noch ignoriert 
 (d.h. To-do-Liste wird gar nicht ausgedruckt), 
 weil wir noch überlegen müssen, *wie* sie ausgedruckt werden sollen. 
-Vielleicht mit Fußnoten?
-""")
+Vielleicht mit Fußnoten?"""))
+    print_empty_rows = models.BooleanField(
+        verbose_name=_("Print empty rows"),
+        help_text=_("""Check this to print also empty rows for later completion."""))
+    ignore_yearly_incomes = models.BooleanField(
+        verbose_name=_("Ignore yearly incomes"),
+        help_text=_("""Check this to ignore yearly incomes in the :ref:`welfare.debts.DebtsByBudget`."""))
     intro = dd.RichTextField(_("Introduction"),format="html",blank=True)
     conclusion = dd.RichTextField(_("Conclusion"),format="html",blank=True)
     dist_amount = dd.PriceField(_("Distributable amount"),default=120,
@@ -247,18 +253,20 @@ The total monthly amount available for debts distribution."""))
             if Entry.objects.filter(budget=self,account__group=g).count():
                 yield g
         
-    def entries_by_group(self,ar,group,**kw):
+    def entries_by_group(self,group,**kw):
         """
         Return a TableRequest showing the Entries for the given `group`, 
         using the table layout depending on AccountType.
         Shows all Entries of the specified `accounts.Group`.
         """
         t = entries_table_for_group(group)
-        sar = ar.spawn(t,master_instance=self,
+        #~ print '20130327 entries_by_group', self, t
+        ar = t.request(self,
             title=unicode(group),
             filter=models.Q(account__group=group),**kw)
+          
         #~ print 20120606, sar
-        return sar
+        return ar
         
     #~ def msum(self,fldname,types=None,**kw): 
         #~ # kw.update(account__yearly=False)
@@ -316,7 +324,7 @@ The total monthly amount available for debts distribution."""))
         self.fill_defaults(ar)
         return kw
         
-    def fill_defaults(self,ar):
+    def fill_defaults(self,ar=None):
         #~ if self.closed:
         if not self.partner or self.build_time:
             return
@@ -325,25 +333,23 @@ The total monthly amount available for debts distribution."""))
         self.save()
         flt = models.Q(required_for_household=True)
         flt = flt | models.Q(required_for_person=True)
-        required = accounts.Account.objects.filter(flt)\
-            .order_by('ref').values_list('id',flat=True)
-        missing = set(required)
-        seqno = 1
-        for e in Entry.objects.filter(budget=self).order_by('seqno'):
-            #~ if e.item.pk in required:
-            missing.discard(e.account.pk)
-            seqno = max(seqno,e.seqno)
-        #~ print 20120411, required, missing
-        for pk in required:
-            if pk in missing:
-                seqno += 1
-                e = Entry(account_id=pk,budget=self,seqno=seqno)
-                e.periods = e.account.periods
-                if e.account.default_amount:
-                    e.amount = e.account.default_amount
-                e.full_clean()
-                e.save()
-                #~ print e
+        #~ required =  # .values_list('id',flat=True)
+        #~ missing = set(required)
+        seqno = 0
+        #~ for e in Entry.objects.filter(budget=self):
+            #~ missing.discard(e.account.pk)
+            #~ seqno = max(seqno,e.seqno)
+        for acc in accounts.Account.objects.filter(flt).order_by('ref'):
+            #~ if pk in missing:
+            seqno += 1
+            e = Entry(account=acc,budget=self,seqno=seqno)
+            e.account_changed(ar)
+            e.periods = e.account.periods
+            if e.account.default_amount:
+                e.amount = e.account.default_amount
+            e.full_clean()
+            e.save()
+            #~ print e
         if self.actor_set.all().count() == 0:
             household = self.partner.get_mti_child('household')
             if household:
@@ -364,26 +370,43 @@ The total monthly amount available for debts distribution."""))
                     a.full_clean()
                     a.save()
             
-    def BudgetSummary(self,ar):
-        return ar.spawn(BudgetSummary,master_instance=self,
-            title=BudgetSummary.label)
+    #~ def BudgetSummary(self,ar=None):
+        #~ if ar is None:
+            #~ return BudgetSummary.request(master_instance=self,title=BudgetSummary.label)
+        #~ return ar.spawn(BudgetSummary,master_instance=self,
+            #~ title=BudgetSummary.label)
         
-    def DistByBudget(self,ar):
-        return ar.spawn(DistByBudget,master_instance=self,
-            title=DistByBudget.label)
+    #~ def DistByBudget(self,ar):
+        #~ return ar.spawn(DistByBudget,master_instance=self,
+            #~ title=DistByBudget.label)
         
         
     @dd.virtualfield(dd.HtmlBox(_("Preview")))
     def preview(self,ar):
+        #~ raise Exception(20130325)
+        #~ if ar is None:
+            #~ ar = Budgets.request(username="rolf")
         chunks = []
         def render(sar):
+            if sar.master_instance is None:
+                #~ raise Exception("20130327")
+                return
+            sar.setup_from(ar)
             chunks.append(E.h2(unicode(sar.get_title())))
             chunks.append(ar.ui.table2xhtml(sar))
             
         for grp in self.account_groups():
-            render(self.entries_by_group(ar,grp))
-        render(self.BudgetSummary(ar))
-        render(self.DistByBudget(ar))
+            render(self.entries_by_group(grp))
+        #~ render(self.BudgetSummary(ar))
+        #~ render(self.ResultByBudget(ar))
+        #~ render(self.DebtsByBudget(ar))
+        #~ render(self.DistByBudget(ar))
+        #~ render(self.result_by_budget())
+        #~ render(self.debts_by_budget())
+        #~ render(self.dist_by_budget(ar))
+        render(ResultByBudget.request(self))
+        render(DebtsByBudget.request(self))
+        render(DistByBudget.request(self))
         return E.div(*chunks)
         
       
@@ -417,14 +440,18 @@ class BudgetDetail(dd.FormLayout):
     
     
     summary_tab = dd.Panel("""
-    BudgetSummary:30x5 summary1
+    summary1:30 summary2:40
     DistByBudget
     """,label = pgettext_lazy(u"debts",u"Summary"))
     
     summary1 = """
+    ResultByBudget
+    DebtsByBudget
+    """
+    summary2 = """
     conclusion:30x5 
     dist_amount build_time
-    print_todos 
+    ignore_yearly_incomes print_empty_rows print_todos
     """
     
     #~ ExpensesSummaryByBudget IncomesSummaryByBudget 
@@ -460,8 +487,6 @@ class Budgets(dd.Table):
 
 
 class MyBudgets(Budgets,mixins.ByUser):
-    """
-    """
     pass
     
 class BudgetsByPartner(Budgets):
@@ -611,7 +636,7 @@ Beschreibung wird automatisch mit der Kontobezeichung
 ausgefüllt. Kann man aber manuell ändern. 
 Wenn man das Konto ändert, gehen manuelle Änderungen in diesem Feld verloren.
 Beim Ausdruck steht in Kolonne "Beschreibung"
-lediglich der Inhalt dieses Feld sowie 
+lediglich der Inhalt dieses Feldes, der eventuellen Bemerkung sowie 
 (falls angegeben bei Schulden) der Partner.""")
     periods = PeriodsField(_("Periods"),
         help_text=u"""\
@@ -660,7 +685,7 @@ Wenn hier ein Betrag steht, darf "Verteilen" nicht angekreuzt sein.
     def account_changed(self,ar):
         if self.account_id:
             self.periods = self.account.periods
-            self.description = unicode(self.account)
+            self.description = dd.babelattr(self.account,'name')
 
     def full_clean(self,*args,**kw):
         if self.periods <= 0:
@@ -735,7 +760,7 @@ class EntriesByBudget(Entries):
     column_names = "account description amount actor:10 periods:10 remark todo seqno"
     hidden_columns = "seqno"
     auto_fit_column_widths = True
-    required=dict(user_groups = ['debts'])
+    required = dict(user_groups = ['debts'])
     #~ required_user_level = None
     order_by = ['seqno']
 
@@ -781,8 +806,9 @@ class PrintEntriesByBudget(dd.VirtualTable):
     @classmethod
     def get_handle_name(self,ar):
         hname = ar.ui._handle_attr_name
-        #~ hname = super(PrintEntriesByBudget,self).get_handle_name(ar)
-        hname += str(len(ar.master_instance.get_actors()))
+        if ar.master_instance is not None:
+            #~ hname = super(PrintEntriesByBudget,self).get_handle_name(ar)
+            hname += str(len(ar.master_instance.get_actors()))
         return hname
         
     @classmethod
@@ -816,11 +842,12 @@ class PrintEntriesByBudget(dd.VirtualTable):
         
     
     class Row:
-        has_data = False
         def __init__(self,e):
+            self.has_data = e.budget.print_empty_rows
             self.description = e.description
             self.periods = e.periods
             self.partner = e.partner
+            self.remarks = []
             self.account = e.account
             #~ self.todos = [''] * len(e.budget.get_actors())
             self.todo = ''
@@ -846,6 +873,8 @@ class PrintEntriesByBudget(dd.VirtualTable):
                 self.has_data = True
                 self.amounts[i] += amount
                 self.total += amount
+            if e.remark:
+                self.remarks.append(e.remark)
             if self.todo:
                 self.todo += ', '
             self.todo += e.todo
@@ -882,9 +911,14 @@ class PrintEntriesByBudget(dd.VirtualTable):
         
     @dd.displayfield(_("Description"))
     def description(self,obj,ar):
+        desc = obj.description
+        if len(obj.remarks) > 0:
+            desc += ' (%s)' % ', '.join(obj.remarks)
         if obj.periods != 1:
-            return "%s (%s / %s)" % (obj.description,obj.total,obj.periods)
-        return obj.description
+            desc += " (%s / %s)" % (obj.total,obj.periods)
+        return desc
+            #~ return "%s (%s / %s)" % (obj.description,obj.total,obj.periods)
+        #~ return obj.description
         
     #~ @dd.displayfield(_("Partner"))
     @dd.virtualfield(models.ForeignKey('contacts.Partner'))
@@ -915,31 +949,23 @@ class PrintEntriesByBudget(dd.VirtualTable):
   
   
 class PrintExpensesByBudget(PrintEntriesByBudget):
-    """
-    Print version of :class:`ExpensesByBudget` table.
-    """
+    """Print version of :class:`ExpensesByBudget` table."""
     _account_type = AccountTypes.expenses
     column_names = "description dynamic_amounts"
         
 class PrintIncomesByBudget(PrintEntriesByBudget):
-    """
-    Print version of :class:`IncomesByBudget` table.
-    """
+    """Print version of :class:`IncomesByBudget` table."""
     _account_type = AccountTypes.incomes
     column_names = "description dynamic_amounts"
     
 class PrintLiabilitiesByBudget(PrintEntriesByBudget):
-    """
-    Print version of :class:`LiabilitiesByBudget` table.
-    """
+    """Print version of :class:`LiabilitiesByBudget` table."""
     _account_type = AccountTypes.liabilities
     #~ column_names = "partner description total monthly_rate todo"
     column_names = "partner:20 description:20 dynamic_amounts"
     
 class PrintAssetsByBudget(PrintEntriesByBudget):
-    """
-    Print version of :class:`AssetsByBudget` table.
-    """
+    """Print version of :class:`AssetsByBudget` table."""
     _account_type = AccountTypes.assets
     column_names = "description dynamic_amounts"
 
@@ -966,38 +992,61 @@ def entries_table_for_group(group):
     
     
     
-class BudgetSummary(dd.VirtualTable):
-    """
-    A virtual table showing a list of summary numbers for this budget.
-    """
-    required=dict(user_groups = ['debts'])
+class SummaryTable(dd.VirtualTable):
     auto_fit_column_widths = True
-    master = Budget
     column_names = "desc amount"
-    label = _("Overview")
     slave_grid_format = 'html'
     
+    @dd.displayfield(_("Description"))
+    def desc(self,row,ar):
+        return row[0]
+        
+    @dd.virtualfield(dd.PriceField(_("Amount")))
+    def amount(self,row,ar):
+        return row[1]
+
+    @classmethod
+    def get_sum_text(self,ar):
+        """
+        Return the text to display on the totals row.
+        """
+        return self.label
+        
     @classmethod
     def get_data_rows(self,ar):
+        for row in self.get_summary_numbers(ar):
+            if row[1]: # don't show summary rows with value 0
+                yield row
+        
+    
+  
+#~ class BudgetSummary(SummaryTable):
+class ResultByBudget(SummaryTable):
+    label = _("Incomes & Expenses")
+    required=dict(user_groups = ['debts'])
+    master = Budget
+    
+    @classmethod
+    def get_summary_numbers(self,ar):
         budget = ar.master_instance
         if budget is None: 
             return
         yield ["Monatliche Einkünfte", budget.sum('amount','I',periods=1)]
-        yi = budget.sum('amount','I',periods=12)
-        if yi:
-            yield [
-              ("Jährliche Einkünfte (%s / 12)" 
-                % decfmt(yi*12,places=2)), 
-              yi]
+        if not budget.ignore_yearly_incomes:
+            yi = budget.sum('amount','I',periods=12)
+            if yi:
+                yield [
+                  ("Jährliche Einkünfte (%s / 12)" 
+                    % decfmt(yi*12,places=2)), 
+                  yi]
               
         a = budget.sum('amount','I',exclude=dict(periods__in=(1,12)))
-        if a:
-            yield ["Einkünfte mit sonstiger Periodizität", a]
+        yield ["Einkünfte mit sonstiger Periodizität", a]
             
         yield ["Monatliche Ausgaben", -budget.sum('amount','E',periods=1)]
-        a = budget.sum('amount','E',exclude=dict(periods__in=(1,12)))
-        if a:
-            yield ["Ausgaben mit sonstiger Periodizität", -a]
+        yield ["Ausgaben mit sonstiger Periodizität", 
+            -budget.sum('amount','E',exclude=dict(periods__in=(1,12)))]
+        
         ye = budget.sum('amount','E',periods=12)
         if ye:
             yield [
@@ -1011,28 +1060,32 @@ class BudgetSummary(dd.VirtualTable):
               #~ u"Monatliche Reserve für sonstige periodische Ausgaben", 
               #~ -ye]
             
-        a = budget.sum('monthly_rate','L')
-        if a:
-            yield ["Raten der laufenden Kredite", -a]
-        #~ yield [u"Total Kredite / Schulden", budget.sum('amount','L')]
-        #~ u"Restbetrag für Kredite und Zahlungsrückstände"
-    
+        yield ["Raten der laufenden Kredite", -budget.sum('monthly_rate','L')]
+            
     @classmethod
     def get_sum_text(self,ar):
-        """
-        Return the text to display on the totals row.
-        """
-        #~ return E.b("Finanzielle Situation")
-        return "Finanzielle Situation"
+        return "Restbetrag für Kredite und Zahlungsrückstände"
         
-    @dd.displayfield(_("Description"))
-    def desc(self,row,ar):
-        return row[0]
         
-    @dd.virtualfield(dd.PriceField(_("Amount")))
-    def amount(self,row,ar):
-        return row[1]
-
+class DebtsByBudget(SummaryTable):
+    label = _("Debts")
+    required=dict(user_groups = ['debts'])
+    master = Budget
+    
+    @classmethod
+    def get_summary_numbers(self,ar):
+        budget = ar.master_instance
+        if budget is None: 
+            return
+        for grp in budget.account_groups('L'):
+            for acc in grp.account_set.all():
+                yield [_("%s (distributable)") % dd.babelattr(acc,'name'), 
+                    budget.sum('amount',account=acc,distribute=True)]
+                yield [dd.babelattr(acc,'name'), 
+                    budget.sum('amount',account=acc,distribute=False)]
+        #~ "Total Kredite / Schulden"
+    
+        
     
 #~ class DistByBudget(LiabilitiesByBudget):
 class DistByBudget(EntriesByBudget):
@@ -1092,6 +1145,14 @@ proportionally distributing the `Distributable amount` among the debtors.
         d.update(amount=_("Debt"))
         return d
     
+    @dd.displayfield(_("Description"))
+    def description(self,obj,ar):
+        desc = obj.description
+        if obj.remark:
+            desc += ' (%s)' % obj.remarks
+        return desc
+            #~ return "%s (%s / %s)" % (obj.description,obj.total,obj.periods)
+        #~ return obj.description
     
     
 MODULE_LABEL = _("Debts mediation")
@@ -1113,8 +1174,8 @@ def site_setup(site):
     #~ site.modules.accounts.Accounts.set_required(
         #~ user_groups=['debts'],user_level='manager')
 
-    site.modules.accounts.Accounts.column_names = "name default_amount required_for_household required_for_person group "
-    site.modules.accounts.AccountsByGroup.column_names = "name default_amount required_for_household required_for_person group "
+    site.modules.accounts.Accounts.column_names = "ref name default_amount required_for_household required_for_person group "
+    site.modules.accounts.AccountsByGroup.column_names = "ref name default_amount required_for_household required_for_person group "
 
 def setup_main_menu(site,ui,profile,m):
     m  = m.add_menu("debts",MODULE_LABEL)
