@@ -32,7 +32,7 @@ from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import pgettext_lazy
+from django.utils.translation import pgettext_lazy as pgettext
 from django.utils.encoding import force_unicode 
 
 #~ import lino
@@ -837,10 +837,6 @@ class Job(SectorFunction):
     """
     A place where a Client can work. The Job Provider
     
-    For illustration, here are the first 5 demo data:
-    
-    .. py2rst:: print jobs.Jobs.request(limit=5).to_rst()
-    
     """
     
     preferred_foreignkey_width = 20 
@@ -979,18 +975,17 @@ class CandidatureStates(dd.ChoiceList):
     verbose_name_plural = _("Candidature states")
     
 add = CandidatureStates.add_item
-add('10', _("Active"),'active')
+add('10', pgettext("jobs","Active"),'active')
 add('20', _("Probation"),'probation')
-add('30', _("Inactive"),'inactive')
+add('25', _("Probation failed"),'failed')
+add('27', pgettext("jobs","Working"),'working')
+add('30', pgettext("jobs","Inactive"),'inactive')
     
 
 class Candidature(SectorFunction):
     """
     A candidature is when a Client applies for a known :class:`Job`.
     
-    For illustration, here are the first 5 demo data:
-    
-    .. py2rst:: print jobs.Candidatures.request(limit=5).to_rst()
     
     """
     class Meta:
@@ -1332,7 +1327,7 @@ class NewJobsOverview(Jobs):
     @dd.displayfield(_("Job"))
     def job_desc(self,obj,ar):
         chunks = [ar.obj2html(obj,unicode(obj.function))]
-        chunks.append(pgettext_lazy("(place)"," at "))
+        chunks.append(pgettext("(place)"," at "))
         chunks.append(ar.obj2html(obj.provider))
         chunks.append(' (%d)' % obj.capacity)
         if obj.remark:
@@ -1340,7 +1335,7 @@ class NewJobsOverview(Jobs):
             chunks.append(E.i(obj.remark))
         return E.p(*chunks)
         
-    @dd.displayfield(_("Working"))
+    @dd.displayfield(pgettext("jobs","Working"))
     def working(self,obj,ar):
         return obj._working
         
