@@ -24,8 +24,8 @@
 SETUP_INFO = dict(name='lino-welfare',
       #~ distclass=MyDistribution,
       #~ dist_dir=os.path.join('docs','dist'),
-      version='1.1.0', 
-      install_requires=['Lino==1.6.3','suds','vobject'],
+      version='1.1.1', 
+      install_requires=['Lino==1.6.4','suds','vobject'],
       #~ version=VERSION,
       description=u"A Lino application for Belgian Public Welfare Centres",
       long_description="""\
@@ -50,33 +50,6 @@ possibly to be maintained by an independant organization.""",
       url="http://welfare.lino-framework.org",
       #~ url=settings.LINO.url,
       license='GPL',
-      packages=[
-        'lino_welfare',
-        'lino_welfare.demo',
-        'lino_welfare.modlib',
-        'lino_welfare.modlib.cbss',
-        'lino_welfare.modlib.cbss.fixtures',
-        'lino_welfare.modlib.cbss.management',
-        'lino_welfare.modlib.cbss.management.commands',
-        'lino_welfare.modlib.cbss.tests',
-        'lino_welfare.modlib.courses',
-        'lino_welfare.modlib.cv',
-        'lino_welfare.modlib.debts',
-        'lino_welfare.modlib.debts.fixtures',
-        'lino_welfare.modlib.isip',
-        'lino_welfare.modlib.jobs',
-        'lino_welfare.modlib.jobs.fixtures',
-        'lino_welfare.modlib.newcomers',
-        'lino_welfare.modlib.newcomers.fixtures',
-        'lino_welfare.modlib.pcsw',
-        'lino_welfare.modlib.pcsw.fixtures',
-        'lino_welfare.modlib.pcsw.management',
-        'lino_welfare.modlib.pcsw.management.commands',
-        'lino_welfare.modlib.pcsw.templates',
-        'lino_welfare.modlib.pcsw.tests',
-        'lino_welfare.modlib.statbel',
-        'lino_welfare.modlib.statbel.fixtures',
-      ],
       classifiers="""\
 Programming Language :: Python
 Programming Language :: Python :: 2
@@ -93,3 +66,41 @@ Topic :: Database :: Front-Ends
 Topic :: Home Automation
 Topic :: Office/Business
 Topic :: Software Development :: Libraries :: Application Frameworks""".splitlines())
+
+SETUP_INFO.update(packages=[
+  'lino_welfare',
+  'lino_welfare.management',
+  'lino_welfare.management.commands',
+  'lino_welfare.tests',
+  'lino_welfare.modlib',
+  'lino_welfare.modlib.cbss',
+  'lino_welfare.modlib.cbss.fixtures',
+  'lino_welfare.modlib.cbss.management',
+  'lino_welfare.modlib.cbss.management.commands',
+  'lino_welfare.modlib.cbss.tests',
+  'lino_welfare.modlib.courses',
+  'lino_welfare.modlib.cv',
+  'lino_welfare.modlib.debts',
+  'lino_welfare.modlib.debts.fixtures',
+  'lino_welfare.modlib.isip',
+  'lino_welfare.modlib.jobs',
+  'lino_welfare.modlib.jobs.fixtures',
+  'lino_welfare.modlib.newcomers',
+  'lino_welfare.modlib.newcomers.fixtures',
+  'lino_welfare.modlib.pcsw',
+  'lino_welfare.fixtures',
+  'lino_welfare.modlib.statbel',
+  'lino_welfare.modlib.statbel.fixtures',
+])
+
+SETUP_INFO.update(message_extractors = {
+    'lino_welfare': [
+        ('**/cache/**',          'ignore', None),
+        ('**.py',                'python', None),
+        ('**.js',                'javascript', None),
+        ('**/templates_jinja/**.html', 'jinja2', None),
+        #~ ('**/templates/**.txt',  'genshi', {
+            #~ 'template_class': 'genshi.template:TextTemplate'
+        #~ })
+    ],
+})
